<?xml version="1.0" ?><!DOCTYPE TS><TS language="ast" version="2.1">
<context>
    <name>CloseConfirmDialog</name>
    <message>
        <location filename="../view/widget/closeconfirmdialog.cpp" line="61"/>
        <source>Please select your operation</source>
        <translation>Esbilla la to operación, por favor</translation>
    </message>
    <message>
        <location filename="../view/widget/closeconfirmdialog.cpp" line="68"/>
        <source>Exit</source>
        <translation>Colar</translation>
    </message>
    <message>
        <location filename="../view/widget/closeconfirmdialog.cpp" line="70"/>
        <source>Minimize to system tray</source>
        <translation>Minimizar a la bandexa&apos;l sistema</translation>
    </message>
    <message>
        <location filename="../view/widget/closeconfirmdialog.cpp" line="79"/>
        <source>Do not ask again</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../view/widget/closeconfirmdialog.cpp" line="90"/>
        <source>Cancel</source>
        <translation>Encaboxar</translation>
    </message>
    <message>
        <location filename="../view/widget/closeconfirmdialog.cpp" line="91"/>
        <source>OK</source>
        <translation>Aceutar</translation>
    </message>
</context>
<context>
    <name>Footer</name>
    <message>
        <location filename="../view/footerwidget.cpp" line="290"/>
        <source>Previous</source>
        <translation>Previo</translation>
    </message>
    <message>
        <location filename="../view/footerwidget.cpp" line="291"/>
        <source>Next</source>
        <translation>Siguiente</translation>
    </message>
    <message>
        <location filename="../view/footerwidget.cpp" line="292"/>
        <source>Play/Pause</source>
        <translation>Reproducir/Posar</translation>
    </message>
    <message>
        <location filename="../view/footerwidget.cpp" line="293"/>
        <source>Favorite</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../view/footerwidget.cpp" line="294"/>
        <source>Lyrics</source>
        <translation>Lletres</translation>
    </message>
    <message>
        <location filename="../view/footerwidget.cpp" line="239"/>
        <source>Unknown Title</source>
        <translation>Títulu desconocíu</translation>
    </message>
    <message>
        <location filename="../view/footerwidget.cpp" line="245"/>
        <location filename="../view/footerwidget.cpp" line="536"/>
        <location filename="../view/footerwidget.cpp" line="718"/>
        <source>Unknown artist</source>
        <translation>Artista desconocíu</translation>
    </message>
    <message>
        <location filename="../view/footerwidget.cpp" line="295"/>
        <source>Play Mode</source>
        <translation>Mou de reproducción</translation>
    </message>
    <message>
        <location filename="../view/footerwidget.cpp" line="296"/>
        <source>Playlist</source>
        <translation>Llista de reproducción</translation>
    </message>
    <message>
        <location filename="../view/footerwidget.cpp" line="696"/>
        <source>List Loop</source>
        <translation>Repitición del llistáu</translation>
    </message>
    <message>
        <location filename="../view/footerwidget.cpp" line="699"/>
        <source>Single Loop</source>
        <translation>Una repitición</translation>
    </message>
    <message>
        <location filename="../view/footerwidget.cpp" line="702"/>
        <source>Shuffle</source>
        <translation>Al debalu</translation>
    </message>
</context>
<context>
    <name>ImportWidget</name>
    <message>
        <location filename="../view/importwidget.cpp" line="73"/>
        <source>Add folder</source>
        <translation>Amestar carpeta</translation>
    </message>
    <message>
        <location filename="../view/importwidget.cpp" line="79"/>
        <location filename="../view/importwidget.cpp" line="120"/>
        <source>Scan</source>
        <translation>Escaniar</translation>
    </message>
    <message>
        <location filename="../view/importwidget.cpp" line="80"/>
        <location filename="../view/importwidget.cpp" line="121"/>
        <source>%1 music directory or drag &amp; drop music file to add music</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../view/importwidget.cpp" line="112"/>
        <source>Loading music, please wait...</source>
        <translation>Cargando música. Espera, por favor...</translation>
    </message>
</context>
<context>
    <name>InfoDialog</name>
    <message>
        <location filename="../view/widget/infodialog.cpp" line="117"/>
        <source>Title:</source>
        <translation>Títulu:</translation>
    </message>
    <message>
        <location filename="../view/widget/infodialog.cpp" line="117"/>
        <source>Artist:</source>
        <translation>Artista:</translation>
    </message>
    <message>
        <location filename="../view/widget/infodialog.cpp" line="118"/>
        <source>Album:</source>
        <translation>Álbum:</translation>
    </message>
    <message>
        <location filename="../view/widget/infodialog.cpp" line="118"/>
        <source>Type:</source>
        <translation>Triba:</translation>
    </message>
    <message>
        <location filename="../view/widget/infodialog.cpp" line="120"/>
        <source>Path:</source>
        <translation>Camín:</translation>
    </message>
    <message>
        <location filename="../view/widget/infodialog.cpp" line="192"/>
        <source>Unknown artist</source>
        <translation>Artista desconocíu</translation>
    </message>
    <message>
        <location filename="../view/widget/infodialog.cpp" line="193"/>
        <source>Unknown album</source>
        <translation>Álbum desconocíu</translation>
    </message>
    <message>
        <location filename="../view/widget/infodialog.cpp" line="119"/>
        <source>Size:</source>
        <translation>Tamañu:</translation>
    </message>
    <message>
        <location filename="../view/widget/infodialog.cpp" line="119"/>
        <source>Duration:</source>
        <translation>Duración</translation>
    </message>
</context>
<context>
    <name>LoadWidget</name>
    <message>
        <location filename="../view/loadwidget.cpp" line="43"/>
        <source>Loading...</source>
        <translation>Cargando...</translation>
    </message>
</context>
<context>
    <name>LyricWidget</name>
    <message>
        <location filename="../view/lyricwidget.cpp" line="166"/>
        <source>Find lyrics</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../view/lyricwidget.cpp" line="170"/>
        <source>Title</source>
        <translation>Títulu</translation>
    </message>
    <message>
        <location filename="../view/lyricwidget.cpp" line="175"/>
        <source>Artist</source>
        <translation>Artista</translation>
    </message>
    <message>
        <location filename="../view/lyricwidget.cpp" line="180"/>
        <source>Search</source>
        <translation>Guetar</translation>
    </message>
    <message>
        <location filename="../view/lyricwidget.cpp" line="213"/>
        <source>Back</source>
        <translation>Atrás</translation>
    </message>
</context>
<context>
    <name>MainFrame</name>
    <message>
        <location filename="../view/mainframe.cpp" line="136"/>
        <source>New playlist</source>
        <translation>Llista nueva de reproducción</translation>
    </message>
    <message>
        <location filename="../view/mainframe.cpp" line="152"/>
        <source>Settings</source>
        <translation>Axustes</translation>
    </message>
    <message>
        <location filename="../view/mainframe.cpp" line="183"/>
        <location filename="../view/mainframe.cpp" line="595"/>
        <source>Exit</source>
        <translation>Colar</translation>
    </message>
    <message>
        <location filename="../view/mainframe.cpp" line="142"/>
        <source>Add folder</source>
        <translation>Amestar carpeta</translation>
    </message>
    <message>
        <location filename="../view/mainframe.cpp" line="147"/>
        <source>Add file</source>
        <translation>Amestar ficheru</translation>
    </message>
    <message>
        <location filename="../view/mainframe.cpp" line="168"/>
        <source>Dark theme</source>
        <translation>Tema prietu</translation>
    </message>
    <message>
        <location filename="../view/mainframe.cpp" line="254"/>
        <source>Deepin Music is a beautiful and simple music player that plays local audios. It supports viewing lyrics during playback, playing lossless audio and playlist customization, etc.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../view/mainframe.cpp" line="592"/>
        <source>Play/Pause</source>
        <translation>Reproducir/Posar</translation>
    </message>
    <message>
        <location filename="../view/mainframe.cpp" line="593"/>
        <source>Previous</source>
        <translation>Previo</translation>
    </message>
    <message>
        <location filename="../view/mainframe.cpp" line="739"/>
        <source>Invalid or non-existent file</source>
        <translation>Ficheru non válidu o inesistente</translation>
    </message>
    <message>
        <location filename="../view/mainframe.cpp" line="760"/>
        <source>Failed to import, no vaild music file found!</source>
        <translation>Fallu al importar. ¡Nun s&apos;alcontraron ficheros válidos!</translation>
    </message>
    <message>
        <location filename="../view/mainframe.cpp" line="1027"/>
        <source>All music</source>
        <translation>Tola música</translation>
    </message>
    <message>
        <location filename="../view/mainframe.cpp" line="740"/>
        <location filename="../view/mainframe.cpp" line="765"/>
        <source>OK</source>
        <translation>Aceutar</translation>
    </message>
    <message>
        <location filename="../view/mainframe.cpp" line="690"/>
        <source>Successfully added to &quot;%1&quot;</source>
        <translation>Amestóse con ésitu a «%1»</translation>
    </message>
    <message>
        <location filename="../view/mainframe.cpp" line="594"/>
        <source>Next</source>
        <translation>Siguiente</translation>
    </message>
</context>
<context>
    <name>MusicListView</name>
    <message>
        <location filename="../view/widget/musiclistview.cpp" line="295"/>
        <source>New playlist</source>
        <translation>Llista nueva de reproducción</translation>
    </message>
    <message>
        <location filename="../view/widget/musiclistview.cpp" line="335"/>
        <source>Play</source>
        <translation>Reproducir</translation>
    </message>
    <message>
        <location filename="../view/widget/musiclistview.cpp" line="337"/>
        <source>Add to playlist</source>
        <translation>Amestar a la llista</translation>
    </message>
    <message>
        <location filename="../view/widget/musiclistview.cpp" line="342"/>
        <source>Display in file manager</source>
        <translation>Amosar nel xestor de ficheros</translation>
    </message>
    <message>
        <location filename="../view/widget/musiclistview.cpp" line="369"/>
        <source>Song info</source>
        <translation>Informaciónd de canción</translation>
    </message>
    <message>
        <location filename="../view/widget/musiclistview.cpp" line="425"/>
        <source>Are you sure you want to delete %1?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../view/widget/musiclistview.cpp" line="427"/>
        <location filename="../view/widget/musiclistview.cpp" line="431"/>
        <source>Are you sure you want to delete the selected %1 songs?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../view/widget/musiclistview.cpp" line="345"/>
        <source>Remove from playlist</source>
        <translation>Desaniciar del llistáu de reproducción</translation>
    </message>
    <message>
        <location filename="../view/widget/musiclistview.cpp" line="346"/>
        <source>Delete from local disk</source>
        <translation>Desaniciar del discu llocal</translation>
    </message>
    <message>
        <location filename="../view/widget/musiclistview.cpp" line="365"/>
        <source>Encoding</source>
        <translation>Codificación</translation>
    </message>
    <message>
        <location filename="../view/widget/musiclistview.cpp" line="415"/>
        <source>Cancel</source>
        <translation>Encaboxar</translation>
    </message>
    <message>
        <location filename="../view/widget/musiclistview.cpp" line="416"/>
        <source>Delete</source>
        <translation>Desaniciar</translation>
    </message>
    <message>
        <location filename="../view/widget/musiclistview.cpp" line="432"/>
        <source>Deleting the current song will also delete the song files contained</source>
        <translation>Desaniciar la canción actual tamién desaniciará los ficheros venceyaos</translation>
    </message>
    <message>
        <location filename="../view/widget/delegate/musicitemdelegate.cpp" line="299"/>
        <source>Unknown artist</source>
        <translation>Artista desconocíu</translation>
    </message>
    <message>
        <location filename="../view/widget/delegate/musicitemdelegate.cpp" line="310"/>
        <source>Unknown album</source>
        <translation>Álbum desconocíu</translation>
    </message>
</context>
<context>
    <name>MusicListWidget</name>
    <message>
        <location filename="../view/musiclistwidget.cpp" line="140"/>
        <source>No Music</source>
        <translation>Nun hai música</translation>
    </message>
    <message>
        <location filename="../view/musiclistwidget.cpp" line="142"/>
        <source>No result found</source>
        <translation>Nun s&apos;alcontraron resultaos</translation>
    </message>
    <message>
        <location filename="../view/musiclistwidget.cpp" line="174"/>
        <source>Play All</source>
        <translation>Reproducir too</translation>
    </message>
    <message>
        <location filename="../view/musiclistwidget.cpp" line="182"/>
        <source>Time added</source>
        <translation>Data d&apos;amiestu</translation>
    </message>
    <message>
        <location filename="../view/musiclistwidget.cpp" line="183"/>
        <source>Title</source>
        <translation>Títulu</translation>
    </message>
    <message>
        <location filename="../view/musiclistwidget.cpp" line="184"/>
        <source>Artist</source>
        <translation>Artista</translation>
    </message>
    <message>
        <location filename="../view/musiclistwidget.cpp" line="185"/>
        <source>Album name</source>
        <translation>Nome d&apos;álbum</translation>
    </message>
    <message>
        <location filename="../view/musiclistwidget.cpp" line="217"/>
        <source>Custom</source>
        <translation>Personalizáu</translation>
    </message>
</context>
<context>
    <name>PlayListItem</name>
    <message>
        <location filename="../view/widget/playlistitem.cpp" line="187"/>
        <source>Are you sure you want to delete this playlist?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../view/widget/playlistitem.cpp" line="194"/>
        <source>Delete</source>
        <translation>Desaniciar</translation>
    </message>
    <message>
        <location filename="../view/widget/playlistitem.cpp" line="193"/>
        <source>Cancel</source>
        <translation>Encaboxar</translation>
    </message>
</context>
<context>
    <name>PlayListView</name>
    <message>
        <location filename="../view/widget/playlistview.cpp" line="186"/>
        <location filename="../view/widget/playlistview.cpp" line="195"/>
        <source>Play</source>
        <translation>Reproducir</translation>
    </message>
    <message>
        <location filename="../view/widget/playlistview.cpp" line="190"/>
        <location filename="../view/widget/playlistview.cpp" line="198"/>
        <source>Rename</source>
        <translation>Renomar</translation>
    </message>
    <message>
        <location filename="../view/widget/playlistview.cpp" line="191"/>
        <location filename="../view/widget/playlistview.cpp" line="202"/>
        <source>Delete</source>
        <translation>Desaniciar</translation>
    </message>
</context>
<context>
    <name>PlaylistManager</name>
    <message>
        <location filename="../core/playlistmanager.cpp" line="79"/>
        <source>New playlist</source>
        <translation>Llista nueva de reproducción</translation>
    </message>
    <message>
        <location filename="../core/playlistmanager.cpp" line="135"/>
        <source>All Music</source>
        <translation>Tola música</translation>
    </message>
    <message>
        <location filename="../core/playlistmanager.cpp" line="141"/>
        <source>My favorites</source>
        <translation>Los mios favoritos</translation>
    </message>
    <message>
        <location filename="../core/playlistmanager.cpp" line="147"/>
        <source>Search result</source>
        <translation>Resultaos de gueta</translation>
    </message>
</context>
<context>
    <name>PlaylistWidget</name>
    <message>
        <location filename="../view/playlistwidget.cpp" line="58"/>
        <source>New playlist</source>
        <translation>Llista nueva de reproducción</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../view/mainframe.cpp" line="256"/>
        <source>Deepin Music</source>
        <translation>Música Deepin</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="87"/>
        <source>Deepin Music</source>
        <translation>Música Deepin</translation>
    </message>
    <message>
        <location filename="../view/widget/settingsdialog.cpp" line="26"/>
        <source>Minimize to system tray</source>
        <translation>Minimizar a la bandexa&apos;l sistema</translation>
    </message>
    <message>
        <location filename="../view/widget/settingsdialog.cpp" line="27"/>
        <source>Exit Deepin Music</source>
        <translation>Colar de Deepin Music</translation>
    </message>
    <message>
        <location filename="../view/widget/settingsdialog.cpp" line="28"/>
        <source>Autoplay</source>
        <translation>Auto-reproducción</translation>
    </message>
    <message>
        <location filename="../view/widget/settingsdialog.cpp" line="29"/>
        <source>Enable fade in/out</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../view/widget/settingsdialog.cpp" line="30"/>
        <source>Remember playback position</source>
        <translation>Recordar posición de reproducción</translation>
    </message>
    <message>
        <location filename="../view/widget/settingsdialog.cpp" line="31"/>
        <source>Close Main Window</source>
        <translation>Zarrar ventana principal</translation>
    </message>
    <message>
        <location filename="../view/widget/settingsdialog.cpp" line="32"/>
        <source>Basic</source>
        <translation>Básicu</translation>
    </message>
    <message>
        <location filename="../view/widget/settingsdialog.cpp" line="33"/>
        <source>Play</source>
        <translation>Reproducir</translation>
    </message>
    <message>
        <location filename="../view/widget/settingsdialog.cpp" line="34"/>
        <source>Shortcuts</source>
        <translation>Atayos</translation>
    </message>
    <message>
        <location filename="../view/widget/settingsdialog.cpp" line="35"/>
        <source>Restore Defaults</source>
        <translation>Reafitar valores</translation>
    </message>
    <message>
        <location filename="../view/widget/settingsdialog.cpp" line="36"/>
        <source>Next</source>
        <translation>Siguiente</translation>
    </message>
    <message>
        <location filename="../view/widget/settingsdialog.cpp" line="37"/>
        <source>Play/Pause</source>
        <translation>Reproducir/Posar</translation>
    </message>
    <message>
        <location filename="../view/widget/settingsdialog.cpp" line="38"/>
        <source>Previous</source>
        <translation>Previo</translation>
    </message>
    <message>
        <location filename="../view/widget/settingsdialog.cpp" line="39"/>
        <source>Volume down</source>
        <translation>Baxar volume</translation>
    </message>
    <message>
        <location filename="../view/widget/settingsdialog.cpp" line="40"/>
        <source>Volume up</source>
        <translation>Xubir volume</translation>
    </message>
</context>
<context>
    <name>SearchResult</name>
    <message>
        <location filename="../view/widget/searchresult.cpp" line="57"/>
        <location filename="../view/widget/searchresult.cpp" line="126"/>
        <source>Search &quot;%1&quot; in Deepin Music</source>
        <translation>Guetar «%1» en Deepin Music</translation>
    </message>
</context>
<context>
    <name>TitlebarWidget</name>
    <message>
        <location filename="../view/widget/titlebarwidget.cpp" line="90"/>
        <source>Search</source>
        <translation>Guetar</translation>
    </message>
</context>
</TS>